#
# spec file for package mono-zeroconf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mono-zeroconf
Summary:        A cross platform Zero Configuration Networking library for Mono
License:        MIT
Group:          Development/Languages/Mono
URL:            http://mono-project.com/Mono.Zeroconf
Version:        0.9.0
Release:        23.1
Source0:        %{name}-%{version}.tar.bz2
Patch0:         mono-search-path.patch
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  mono-devel
Requires:       mono-zeroconf-provider
%define assembly_version 4.0.0.90
## --- Build Configuration --- ##
%define build_avahi 1
%define build_mdnsr 1
%define build_docs 1
# openSUSE Configuration
%if 0%{?suse_version}
%if %{suse_version} >= 1030
%define build_avahi 1
%define build_mdnsr 0
%endif
%if %{suse_version} >= 1020 && %{suse_version} < 1030
%define build_avahi 1
%define build_mdnsr 1
%endif
%if %{suse_version} < 1020
%define build_avahi 0
%define build_mdnsr 1
%endif
%endif
# Fedora Configuration
%if 0%{?fedora_version}
%define env_options export MONO_SHARED_DIR=/tmp
%define build_docs 0
%define build_mdnsr 0
%define build_avahi 1
%endif
# Mandriva Configuration
%if 0%{?mandriva_version}
%define build_docs 0
%define build_avahi 1
%define build_mdnsr 0
%endif
%if 0%{?build_docs}
BuildRequires:  monodoc-core
%endif
## --- Base Package Information --- ##

%description
Mono.Zeroconf is a cross platform Zero Configuration Networking library
for Mono and .NET. It provides a unified API for performing the most
common zeroconf operations on a variety of platforms and subsystems:
all the operating systems supported by Mono and both the Avahi and
Bonjour/mDNSResponder transports.



Authors:
--------
    Aaron Bockover <abockover@novell.com>

%files
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%dir %_prefix/lib/mono-zeroconf
%dir %_prefix/lib/mono/mono-zeroconf
%dir %_prefix/lib/mono/gac/Mono.Zeroconf
%dir %_prefix/lib/mono/gac/Mono.Zeroconf/%{assembly_version}__e60c4f4a95e1099e
%dir %_prefix/lib/mono/gac/policy.1.0.Mono.Zeroconf
%dir %_prefix/lib/mono/gac/policy.1.0.Mono.Zeroconf/0.0.0.0__e60c4f4a95e1099e
%dir %_prefix/lib/mono/gac/policy.2.0.Mono.Zeroconf
%dir %_prefix/lib/mono/gac/policy.2.0.Mono.Zeroconf/0.0.0.0__e60c4f4a95e1099e
%dir %_prefix/lib/mono/gac/policy.3.0.Mono.Zeroconf
%dir %_prefix/lib/mono/gac/policy.3.0.Mono.Zeroconf/0.0.0.0__e60c4f4a95e1099e
%dir %_prefix/lib/mono/gac/policy.4.0.Mono.Zeroconf
%dir %_prefix/lib/mono/gac/policy.4.0.Mono.Zeroconf/0.0.0.0__e60c4f4a95e1099e
%_bindir/mzclient
%_prefix/lib/mono/gac/Mono.Zeroconf/*/*.dll*
%_prefix/lib/mono/gac/policy.1.0.Mono.Zeroconf/*/*
%_prefix/lib/mono/gac/policy.2.0.Mono.Zeroconf/*/*
%_prefix/lib/mono/gac/policy.3.0.Mono.Zeroconf/*/*
%_prefix/lib/mono/gac/policy.4.0.Mono.Zeroconf/*/*
%_prefix/lib/mono/mono-zeroconf/Mono.Zeroconf.dll*
%_prefix/lib/mono-zeroconf/MZClient.exe*
## --- mDNSResponder Provider --- ##
%if %{build_mdnsr} == 1

%package provider-mDNSResponder
Summary:        A cross platform Zero Configuration Networking library for Mono
Group:          Development/Languages/Mono
BuildRequires:  mDNSResponder-devel
Requires:       mDNSResponder
Provides:       mono-zeroconf-provider

%description provider-mDNSResponder
Mono.Zeroconf is a cross platform Zero Configuration Networking library
for Mono and .NET. It provides a unified API for performing the most
common zeroconf operations on a variety of platforms and subsystems:
all the operating systems supported by Mono and both the Avahi and
Bonjour/mDNSResponder transports.



Authors:
--------
    Aaron Bockover <abockover@novell.com>

%files provider-mDNSResponder
%defattr(-, root, root)
%dir %_prefix/lib/mono-zeroconf
%_prefix/lib/mono-zeroconf/Mono.Zeroconf.Providers.Bonjour.dll*
%endif
## --- Avahi Provider --- ##
%if %{build_avahi} == 1

%package provider-avahi
Summary:        A cross platform Zero Configuration Networking library for Mono
Group:          Development/Languages/Mono
Requires:       avahi
Provides:       mono-zeroconf-provider

%description provider-avahi
Mono.Zeroconf is a cross platform Zero Configuration Networking library
for Mono and .NET. It provides a unified API for performing the most
common zeroconf operations on a variety of platforms and subsystems:
all the operating systems supported by Mono and both the Avahi and
Bonjour/mDNSResponder transports.



Authors:
--------
    Aaron Bockover <abockover@novell.com>

%files provider-avahi
%defattr(-, root, root)
%dir %_prefix/lib/mono-zeroconf
%_prefix/lib/mono-zeroconf/Mono.Zeroconf.Providers.AvahiDBus.dll*
%endif
## --- Monodoc Developer API Documentation --- ##
%if %{build_docs} == 1

%package doc
Summary:        A cross platform Zero Configuration Networking library for Mono
Group:          Development/Languages/Mono

%description doc
Mono.Zeroconf is a cross platform Zero Configuration Networking library
for Mono and .NET. It provides a unified API for performing the most
common zeroconf operations on a variety of platforms and subsystems:
all the operating systems supported by Mono and both the Avahi and
Bonjour/mDNSResponder transports.



Authors:
--------
    Aaron Bockover <abockover@novell.com>

%files doc
%defattr(-, root, root)
%dir %_prefix/lib/monodoc/sources/
%_prefix/lib/monodoc/sources/mono-zeroconf-docs*
%endif
## --- Devel Package (pkg-config file) --- ##

%package devel
Summary:        A cross platform Zero Configuration Networking library for Mono
Group:          Development/Languages/Mono
Requires:       %{name} = %{version}

%description devel
Mono.Zeroconf is a cross platform Zero Configuration Networking library
for Mono and .NET. It provides a unified API for performing the most
common zeroconf operations on a variety of platforms and subsystems:
all the operating systems supported by Mono and both the Avahi and
Bonjour/mDNSResponder transports.



Authors:
--------
    Aaron Bockover <abockover@novell.com>

%files devel
%defattr(-, root, root)
%_prefix/share/pkgconfig/mono-zeroconf.pc
## --- Build/Install --- #

%prep
%setup -q
%define mcsver %({ mcs --version | awk '{print $5}' | cut -f1 -d"." ; mcs --version | awk '{print $5}' | cut -f2 -d"." ; } | xargs printf "%03d")
%if 0%{?mcsver} >= 4004
%patch -P 0 -p1
%endif

%build
%{?env_options}
./configure --prefix=/usr \
%if %{build_docs} == 0
	--disable-docs \
%else
	--enable-docs \
%endif
%if %{build_avahi} == 0
	--disable-avahi \
%else
	--enable-avahi \
%endif
%if %{build_mdnsr} == 0
	--disable-mdnsresponder
%else
	--enable-mdnsresponder
%endif
make

%install
%{?env_options}
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/share/pkgconfig
mv $RPM_BUILD_ROOT/usr/lib/pkgconfig/* $RPM_BUILD_ROOT/usr/share/pkgconfig

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Thu Feb 22 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Jun  5 2016 fwdsbs.to.11df@xoxy.net
- Added patch mono-search-path.patch:
  * Added alternative search path in configure script for System.dll and System.Web.dll in order to fix build with mono 4.4.0 and up
* Wed May  6 2009 abockover@novell.com
- Require: mono-zeroconf in the -devel package
* Tue May  5 2009 abockover@novell.com
- Updated to version 0.9.0
- Fixed major bug in Avahi service registration
- Introduced a workaround unsigned short port property, UPort to
  eliminate having to do an unchecked cast to short for port values
  that overflow Int16
- Clean up some packaging, do not BuildRequires avahi-sharp since
  we use the DBus API directly since 0.8.0
- Split the .pc file into a -devel package
* Tue Apr  7 2009 ajorgensen@novell.com
- Patch to build against mono 2.4
* Thu Sep 11 2008 abockover@suse.de
- Updated to version 0.8.0
- New Avahi provider using DBus instead of libavahi
- Improved IPv6 support (AddressProtocol/A6 query support)
- Garbage Collection bug fixed in the Bonjour backend
- New MZClient features: setting interface, domain, address type
  restrictions on browse/resolve operations
* Fri Mar 21 2008 abockover@suse.de
- Updated to version 0.7.6
- Adds NetworkInterface API to IService objects
- Supports IPv6 host address resolutions
* Fri Jan 25 2008 abockover@suse.de
- Updated to version 0.7.5
- Adds GAC version policy assemblies so package upgrades don't break apps
* Wed Jan 23 2008 abockover@suse.de
- Updated to version 0.7.4
- Fixes IP address resolution bug in Bonjour provider that
  only manifested under .NET on Windows XP SP2
- Minor bug fix in MZClient
- libdir patch removed from package; fixed in upstream release
* Thu Dec 27 2007 abockover@suse.de
- Patch to fix libdir issue in mono-zeroconf.pc on x86_64
* Sun Dec 23 2007 abockover@suse.de
- Initial import of Mono.Zeroconf for STABLE from the build serivce
- Version 0.7.3 release
- Provides a cross platform (Linux, Mac, Windows) Mono/.NET API
  for Zero Configuration networking supporting either Bonjour
  or Avahi mDNS providers
